MinLengthValidator class

Ensures the value length contains no fewer than a set number of characters.

Inheritance

Constructors

MinLengthValidator({required int min, required String error, bool ignoreEmptyValues = true})
const

Properties

error → String
The error to display when the validation fails
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
ignoreEmptyValues → bool
finalinherited
min → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

call(String? value) → String?
Call is a special function that makes a class callable returns null if the input is valid otherwise it returns the provided error
inherited
hasMatch(String pattern, String input, {bool caseSensitive = true}) → bool
Method to check if an input matches a given pattern
inherited
isValid(String? value) → bool
Checks the input against the given conditions
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited